@@ -15,6 +15,7 @@
 #' @examples
 #' # to be added
 hclust_haystack_highD = function(x, detection, genes, method="ward.D", grid.coordinates = NULL, scale = TRUE){
+  .Deprecated(msg = "This function has been deprecated and will be removed in the future.")
 
   # if data.frame, convert to matrix
   if(is.data.frame(x))
@@ -76,13 +77,13 @@ hclust_haystack_highD = function(x, detection, genes, method="ward.D", grid.coor
   if(is.matrix(detection)){
     for(g in 1:length(row.index.subset)){
       gene_index <- row.index.subset[g]
-      densities[g,] <- apply(density.contributions[detection[gene_index,],],2,sum)
+      densities[g,] <- colSums(density.contributions[detection[gene_index,],,drop=FALSE])
       setTxtProgressBar(pb, g) # progress bar
     }
   } else if( inherits(detection, "lgRMatrix") ){
     for(g in 1:length(row.index.subset)){
       gene_index <- row.index.subset[g]
-      densities[g,] <- apply(density.contributions[extract_row_lgRMatrix(detection,gene_index),],2,sum)
+      densities[g,] <- colSums(density.contributions[extract_row_lgRMatrix(detection,gene_index),,drop=FALSE])
       setTxtProgressBar(pb, g) # progress bar
     }
   } else {
@@ -94,7 +95,7 @@ hclust_haystack_highD = function(x, detection, genes, method="ward.D", grid.coor
   #heatmap(densities, Rowv=NA, Colv=NA, scale="none")
 
   # rescale to sum to 1. This is to avoid R thinking sd=0 in the case where an entire row has very low values
-  densities <- densities / apply(densities,1,sum)
+  densities <- densities / rowSums(densities)
 
   dist <- as.dist(1 - cor(t(densities),method = "spearman")) # dist(densities)
   hc <- hclust(dist, method=method)
@@ -119,6 +120,7 @@ hclust_haystack_highD = function(x, detection, genes, method="ward.D", grid.coor
 #' @examples
 #' # to be added
 kmeans_haystack_highD = function(x, detection, genes, grid.coordinates = NULL, k, scale = TRUE, ...){
+  .Deprecated(msg = "This function has been deprecated and will be removed in the future.")
 
   # if data.frame, convert to matrix
   if(is.data.frame(x))
@@ -182,13 +184,13 @@ kmeans_haystack_highD = function(x, detection, genes, grid.coordinates = NULL, k
   if(is.matrix(detection)){
     for(g in 1:length(row.index.subset)){
       gene_index <- row.index.subset[g]
-      densities[g,] <- apply(density.contributions[detection[gene_index,],],2,sum)
+      densities[g,] <- colSums(density.contributions[detection[gene_index,],,drop=FALSE])
       setTxtProgressBar(pb, g) # progress bar
     }
   } else if( inherits(detection, "lgRMatrix") ){
     for(g in 1:length(row.index.subset)){
       gene_index <- row.index.subset[g]
-      densities[g,] <- apply(density.contributions[extract_row_lgRMatrix(detection,gene_index),],2,sum)
+      densities[g,] <- colSums(density.contributions[extract_row_lgRMatrix(detection,gene_index),,drop=FALSE])
       setTxtProgressBar(pb, g) # progress bar
     }
   } else {
